export enum ProfitStatus {
  /**
   * 待处理/待计算 (例如，等待上游数据或条件满足)
   */
  PENDING_CALCULATION = 'PENDING_CALCULATION',

  /**
   * 待直接结算/待直接分账 (例如，T+7 到账)
   * 这种类型的佣金会计入银行账户，而非平台余额
   */
  DIRECT_SETTLEMENT_PENDING = 'DIRECT_SETTLEMENT_PENDING',

  /**
   * 直接结算已完成/直接分账已完成
   */
  DIRECT_SETTLEMENT_PROCESSING = 'DIRECT_SETTLEMENT_PROCESSING',

  /**
   * 间接收益已结算到合伙人余额 (例如，主播推荐奖金进入可提现余额)
   */
  INDIRECT_SETTLED_TO_BALANCE = 'INDIRECT_SETTLED_TO_BALANCE',

  /**
   * 佣金已取消 (例如，订单退款，不满足条件等)
   */
  CANCELLED = 'CANCELLED',

  /**
   * 佣金处理失败
   */
  FAILED = 'FAILED',

  /**
   * 其他状态
   */
  OTHER = 'OTHER',

  /**
   * 已完成
   */
  FINISHED = 'FINISHED',
}

// 如果需要为每个枚举值添加描述，可以使用一个单独的映射对象
export const ProfitStatusDescriptions = {
  PENDING_CALCULATION: '',
  DIRECT_SETTLEMENT_PENDING: '待分账',
  DIRECT_SETTLEMENT_PROCESSING: '',
  INDIRECT_SETTLED_TO_BALANCE: '',
  CANCELLED: '',
  FAILED: '',
  OTHER: '',
  FINISHED: '已分账',
};

export const WithdrawStatusDescriptions = {
  0: '提现中',
  1: '已提现',
  2: '失败',
};
